@@ -75,6 +75,11 @@ class ProxyPool:
             print useful messages for debugging
         """
 
+        if not connection_check_on_start and num_top_proxies is not None:
+            print("'num_top_proxies' is set to yet 'check_on_start' is not True."
+                  "This means that pool size will be reduced to num_top_proxies per proxy type, yet it's not "
+                  "guaranteed that those proxies are with the best connection out of all provided proxies.")
+
         self.__pool = PriorityQueue()
         self.__test_url = test_url
         self.__fail_predicate_fn = fail_predicate_fn
